# Purpose: Setup and initialize the dock bar gui interfaces
#
# $Id: FRBrowserRenderFox.rb,v 1.4 2002/08/09 20:19:15 ljulliar Exp $
#
# Authors:  NISHIO Mizuho
# Contributors:
#
# This file is part of the FreeRIDE project
#
# This application is free software; you can redistribute it and/or
# modify it under the terms of the Ruby license defined in the
# COPYING file.
#
# Copyright (c) 2002 NISHIO Mizuho. All rights reserved.
#

require 'fox'
#require 'fox/responder'
#require 'fox/colors'
require 'plugins/FRBrowser/Render/Fox/tree'




module FreeRIDE

  module FRBrowserRenderFox
      
    extend FreeBASE::StandardPlugin
    
    def self.start(plugin)
      Listener.new(plugin, "/system/ui/components/FRBrowser/render")
    end
    
    class Listener
      attr_reader :plugin
      @@browser_inited = false
      
      def initialize(plugin, base_path)
	@plugin = plugin
	@base_slot = @plugin[base_path]
	@log_info = @plugin["./log/info"]
	@log_error = @plugin["./log/error"]
	@log_info << "Browser Listener started"
	render_slot = @base_slot["."]
	
	render_slot.subscribe do |event, slot|
	  case event
	  when :notify_slot_add
	    # if pool slot is accessed 
	    if (slot.name == 'init')
	      if @@browser_inited 
		@log_error << "Browser has already been initialized, #{slot.path} ignored."
	      else
		@@browser_inited = true
		FRBrowserRenderFox.init_renderer(@plugin, @base_slot)
	      end
	    end
	  end
	end
	
	# Force notification events for any slots that existed before we subscribed
	# browser_pool.each_slot { |slot| slot.notify(:notify_data_set)}
	
	# Now only is the plugin ready
	plugin.transition(FreeBASE::RUNNING)
      end
	
    end  # class Listener

    # base_slot "/system/ui/components/FRBrowser/render"
    def self.init_renderer(plugin, base_slot)

      main = plugin["/system/ui/fox/FXMainWindow"].data
      @frm = Fox::FXHorizontalFrame.new(main, FRAME_SUNKEN|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0)      
      @tree = Tree.new(@frm)

      frame_slot = base_slot["/system/ui/components/FRBrowser/render/frame"]
      frame_slot.attr_frame = @frm

      @frm.hSpacing = 0
      @frm.vSpacing = 0
      @frm.create
    end # self.init

    def self.__browser_frame__
      @frm
    end

    def self.__tree__
      @tree
    end
    
  end # module # FRBrowserRenderFox

end # module FreeRIDE
